@@ -294,6 +294,14 @@ SEXP initialize_factors_mat(SEXP dim1, SEXP dim2)
     return out;
 }
 
+SEXP R_has_openmp()
+{
+    #ifdef _OPENMP
+    return Rf_ScalarLogical(1);
+    #else
+    return Rf_ScalarLogical(0);
+    #endif
+}
 
 static const R_CallMethodDef callMethods [] = {
     {"wrapper_run_poismf", (DL_FUNC) &wrapper_run_poismf, 23},
@@ -304,6 +312,7 @@ static const R_CallMethodDef callMethods [] = {
     {"wrapper_topN", (DL_FUNC) &wrapper_topN, 9},
     {"check_size_below_int_max", (DL_FUNC) &check_size_below_int_max, 2},
     {"initialize_factors_mat", (DL_FUNC) &initialize_factors_mat, 2},
+    {"R_has_openmp", (DL_FUNC) &R_has_openmp, 0},
     {NULL, NULL, 0}
 }; 
 
